@@ -134,7 +134,7 @@ will be invisible as soon as the X server decides to hide it.")
 The toolbar instantiator used is taken from the 'floating-toolbar
 property of any extent under the mouse.  If no such non-nil
 property exists for any extent under the mouse, then the value of the
-variable `floating-toolbar' is checked.  If its value si nil, then
+variable `floating-toolbar' is checked.  If its value is nil, then
 no toolbar will be displayed.
 
 This command should be bound to a button press event.
